==> pexsi_v0.9.2.tar.gz: pexsi_v0.9.2/doc/download.md <==
Download       {#pageDownload}
========

**Beta version (v0.9.2)**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.9.2.tar.gz">pexsi_v0.9.2.tar.gz</a>

**Stable version (v0.9.0)**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.9.0.tar.gz">pexsi_v0.9.0.tar.gz</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.9.0">[html]</a>

**Older version of %PEXSI**:

**NOTE: Due to insufficient manpower (as there will never be in science), older version of PEXSI is no longer
supported**

**v0.8.0**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.8.0.tar.gz">pexsi_v0.8.0.tar.gz</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.8.0">[html]</a>

**v0.7.3**:
- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.7.3.tar.gz">pexsi_v0.7.3.tar.gz</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.7.3">[html]</a>

**v0.7.2**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.7.2.tar.gz">[pexsi_v0.7.2.tar.gz]</a>

**v0.7.1**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.7.1.tar.gz">[pexsi_v0.7.1.tar.gz]</a>
<!--
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.7.1">[html]</a>
-->

**v0.6.0**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.6.0.tar.gz">[pexsi_v0.6.0.tar.gz]</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.6.0">[html]</a>

==> pexsi_v0.10.2.tar.gz: pexsi_v0.10.2/doc/download.md <==
Download       {#pageDownload}
========

%PEXSI is Moving **steadily** towards v1.0.0...

**Beta version (v0.10.2)**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.10.2.tar.gz">pexsi_v0.10.2.tar.gz</a>

- Read @ref pageImportantChange for the important interface changes since v0.10.0

**Stable version (v0.9.2)**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.9.2.tar.gz">pexsi_v0.9.2.tar.gz</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.9.2">[html]</a>


**Older version of %PEXSI**:

**NOTE: Due to insufficient manpower (as there will never be in science), older version of %PEXSI is no longer
supported**

**v0.9.0**:
- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.9.0.tar.gz">pexsi_v0.9.0.tar.gz</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.9.0">[html]</a>


**v0.8.0**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.8.0.tar.gz">pexsi_v0.8.0.tar.gz</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.8.0">[html]</a>

**v0.7.3**:
- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.7.3.tar.gz">pexsi_v0.7.3.tar.gz</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.7.3">[html]</a>

**v0.7.2**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.7.2.tar.gz">[pexsi_v0.7.2.tar.gz]</a>

**v0.7.1**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.7.1.tar.gz">[pexsi_v0.7.1.tar.gz]</a>
<!--
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.7.1">[html]</a>
-->

**v0.6.0**:

- Code: <a href="https://math.berkeley.edu/~linlin/pexsi/download/download.php?file=pexsi_v0.6.0.tar.gz">[pexsi_v0.6.0.tar.gz]</a>
- Documentation: <a href="https://math.berkeley.edu/~linlin/pexsi/download/doc_v0.6.0">[html]</a>
